linux-kernel.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
* [PATCH v2 0/2] some checkpatch fixes in the file rxtx.c
@ 2022-11-01 12:37 Tanjuate Brunostar
  2022-11-01 12:37 ` [PATCH v2 1/2] change the function name s_vFillRTSHead Tanjuate Brunostar
                   ` (2 more replies)
  0 siblings, 3 replies; 7+ messages in thread
From: Tanjuate Brunostar @ 2022-11-01 12:37 UTC (permalink / raw)
  To: gregkh; +Cc: linux-staging, linux-kernel, outreachy, Tanjuate Brunostar

These fixes are focused on the function s_vFillRTSHead

v2: changed confusing changelog messages

Tanjuate Brunostar (2):
  change the function name s_vFillRTSHead
  Join some lines of code to avoid code lines ending in (

 drivers/staging/vt6655/rxtx.c | 48 ++++++++++++++++-------------------
 1 file changed, 22 insertions(+), 26 deletions(-)

-- 
2.34.1


^ permalink raw reply	[flat|nested] 7+ messages in thread

* [PATCH v2 1/2] change the function name s_vFillRTSHead
  2022-11-01 12:37 [PATCH v2 0/2] some checkpatch fixes in the file rxtx.c Tanjuate Brunostar
@ 2022-11-01 12:37 ` Tanjuate Brunostar
  2022-11-01 13:32   ` Joe Perches
  2022-11-01 12:38 ` [PATCH v2 2/2] Join some lines of code to avoid code lines ending in ( Tanjuate Brunostar
  2022-11-01 18:21 ` [PATCH v2 0/2] some checkpatch fixes in the file rxtx.c Greg KH
  2 siblings, 1 reply; 7+ messages in thread
From: Tanjuate Brunostar @ 2022-11-01 12:37 UTC (permalink / raw)
  To: gregkh; +Cc: linux-staging, linux-kernel, outreachy, Tanjuate Brunostar

Remove the use of Hungarian notation, which is not used in the Linux
kernel. Reported by checkpatch

Signed-off-by: Tanjuate Brunostar <tanjubrunostar0@gmail.com>
---
 drivers/staging/vt6655/rxtx.c | 26 +++++++++++++-------------
 1 file changed, 13 insertions(+), 13 deletions(-)

-- 
2.34.1


^ permalink raw reply related	[flat|nested] 7+ messages in thread

* [PATCH v2 2/2] Join some lines of code to avoid code lines ending in (
  2022-11-01 12:37 [PATCH v2 0/2] some checkpatch fixes in the file rxtx.c Tanjuate Brunostar
  2022-11-01 12:37 ` [PATCH v2 1/2] change the function name s_vFillRTSHead Tanjuate Brunostar
@ 2022-11-01 12:38 ` Tanjuate Brunostar
  2022-11-01 18:21 ` [PATCH v2 0/2] some checkpatch fixes in the file rxtx.c Greg KH
  2 siblings, 0 replies; 7+ messages in thread
From: Tanjuate Brunostar @ 2022-11-01 12:38 UTC (permalink / raw)
  To: gregkh; +Cc: linux-staging, linux-kernel, outreachy, Tanjuate Brunostar

Fix checkpatch error related to code line ends with a '(', by joining
some lines and indenting correctly. This improves visibility

Signed-off-by: Tanjuate Brunostar <tanjubrunostar0@gmail.com>
---
 drivers/staging/vt6655/rxtx.c | 22 +++++++++-------------
 1 file changed, 9 insertions(+), 13 deletions(-)

diff --git a/drivers/staging/vt6655/rxtx.c b/drivers/staging/vt6655/rxtx.c
index d7e439cd8675..df7473155704 100644
--- a/drivers/staging/vt6655/rxtx.c
+++ b/drivers/staging/vt6655/rxtx.c
@@ -555,19 +555,15 @@ s_uFillDataHead(
 	return buf->duration;
 }
 
-static
-void
-s_vFillRTSHead(
-	struct vnt_private *pDevice,
-	unsigned char byPktType,
-	void *pvRTS,
-	unsigned int cbFrameLength,
-	bool bNeedAck,
-	bool bDisCRC,
-	struct ieee80211_hdr *hdr,
-	unsigned short wCurrentRate,
-	unsigned char byFBOption
-)
+static void fill_rts_head(struct vnt_private *pDevice,
+			  unsigned char byPktType,
+			  void *pvRTS,
+			  unsigned int cbFrameLength,
+			  bool bNeedAck,
+			  bool bDisCRC,
+			  struct ieee80211_hdr *hdr,
+			  unsigned short wCurrentRate,
+			  unsigned char byFBOption)
 {
 	unsigned int uRTSFrameLen = 20;
 
diff --git a/drivers/staging/vt6655/rxtx.c b/drivers/staging/vt6655/rxtx.c
index 31ae99b3cb35..d7e439cd8675 100644
--- a/drivers/staging/vt6655/rxtx.c
+++ b/drivers/staging/vt6655/rxtx.c
@@ -23,7 +23,7 @@
  *      s_uGetTxRsvTime- get frame reserved time
  *      s_vFillCTSHead- fulfill CTS ctl header
  *      s_vFillFragParameter- Set fragment ctl parameter.
  *      s_vFillRTSHead- fulfill RTS ctl header
  *      s_vFillTxKey- fulfill tx encrypt key
  *      s_vSWencryption- Software encrypt header
  *      vDMA0_tx_80211- tx 802.11 frame via dma0
@@ -85,15 +85,15 @@ static const unsigned short fb_opt1[2][5] = {
 #define DATADUR_A_F1    13
 
 /*---------------------  Static Functions  --------------------------*/
-static void s_vFillRTSHead(struct vnt_private *pDevice,
-			   unsigned char byPktType,
-			   void *pvRTS,
-			   unsigned int	cbFrameLength,
-			   bool bNeedAck,
-			   bool bDisCRC,
-			   struct ieee80211_hdr *hdr,
-			   unsigned short wCurrentRate,
-			   unsigned char byFBOption);
+static void fill_rts_head(struct vnt_private *pDevice,
+			  unsigned char byPktType,
+			  void *pvRTS,
+			  unsigned int	cbFrameLength,
+			  bool bNeedAck,
+			  bool bDisCRC,
+			  struct ieee80211_hdr *hdr,
+			  unsigned short wCurrentRate,
+			  unsigned char byFBOption);
 
 static void s_vGenerateTxParameter(struct vnt_private *pDevice,
 				   unsigned char byPktType,
@@ -912,7 +912,7 @@ s_vGenerateTxParameter(
 			buf->rrv_time_a = vnt_rxtx_rsvtime_le16(pDevice, byPktType, cbFrameSize, wCurrentRate, bNeedACK);
 			buf->rrv_time_b = vnt_rxtx_rsvtime_le16(pDevice, PK_TYPE_11B, cbFrameSize, pDevice->byTopCCKBasicRate, bNeedACK);
 
-			s_vFillRTSHead(pDevice, byPktType, pvRTS, cbFrameSize, bNeedACK, bDisCRC, psEthHeader, wCurrentRate, byFBOption);
+			fill_rts_head(pDevice, byPktType, pvRTS, cbFrameSize, bNeedACK, bDisCRC, psEthHeader, wCurrentRate, byFBOption);
 		} else {/* RTS_needless, PCF mode */
 			struct vnt_rrv_time_cts *buf = pvRrvTime;
 
@@ -931,7 +931,7 @@ s_vGenerateTxParameter(
 			buf->rrv_time = vnt_rxtx_rsvtime_le16(pDevice, byPktType, cbFrameSize, wCurrentRate, bNeedACK);
 
 			/* Fill RTS */
-			s_vFillRTSHead(pDevice, byPktType, pvRTS, cbFrameSize, bNeedACK, bDisCRC, psEthHeader, wCurrentRate, byFBOption);
+			fill_rts_head(pDevice, byPktType, pvRTS, cbFrameSize, bNeedACK, bDisCRC, psEthHeader, wCurrentRate, byFBOption);
 		} else if (!pvRTS) {/* RTS_needless, non PCF mode */
 			struct vnt_rrv_time_ab *buf = pvRrvTime;
 
@@ -945,7 +945,7 @@ s_vGenerateTxParameter(
 			buf->rrv_time = vnt_rxtx_rsvtime_le16(pDevice, PK_TYPE_11B, cbFrameSize, wCurrentRate, bNeedACK);
 
 			/* Fill RTS */
-			s_vFillRTSHead(pDevice, byPktType, pvRTS, cbFrameSize, bNeedACK, bDisCRC, psEthHeader, wCurrentRate, byFBOption);
+			fill_rts_head(pDevice, byPktType, pvRTS, cbFrameSize, bNeedACK, bDisCRC, psEthHeader, wCurrentRate, byFBOption);
 		} else { /* RTS_needless, non PCF mode */
 			struct vnt_rrv_time_ab *buf = pvRrvTime;
 
@@ -23,7 +23,7 @@
  *      s_vFillCTSHead- fulfill CTS ctl header
  *      s_vFillFragParameter- Set fragment ctl parameter.
- *      s_vFillRTSHead- fulfill RTS ctl header
+ *      fill_rts_head- fulfill RTS ctl header
  *      s_vFillTxKey- fulfill tx encrypt key
  *      s_vSWencryption- Software encrypt header
-- 
2.34.1


^ permalink raw reply related	[flat|nested] 7+ messages in thread

* Re: [PATCH v2 1/2] change the function name s_vFillRTSHead
  2022-11-01 12:37 ` [PATCH v2 1/2] change the function name s_vFillRTSHead Tanjuate Brunostar
@ 2022-11-01 13:32   ` Joe Perches
  2022-11-01 14:55     ` Tanju Brunostar
  0 siblings, 1 reply; 7+ messages in thread
From: Joe Perches @ 2022-11-01 13:32 UTC (permalink / raw)
  To: Tanjuate Brunostar, gregkh; +Cc: linux-staging, linux-kernel, outreachy

On Tue, 2022-11-01 at 12:37 +0000, Tanjuate Brunostar wrote:
> Remove the use of Hungarian notation, which is not used in the Linux
> kernel. Reported by checkpatch
[]
> diff --git a/drivers/staging/vt6655/rxtx.c b/drivers/staging/vt6655/rxtx.c
[]
> @@ -23,7 +23,7 @@
>   *      s_uGetTxRsvTime- get frame reserved time
>   *      s_vFillCTSHead- fulfill CTS ctl header
>   *      s_vFillFragParameter- Set fragment ctl parameter.
> - *      s_vFillRTSHead- fulfill RTS ctl header
> + *      fill_rts_head- fulfill RTS ctl header

Perhaps use header as head is conventionally used in lists.

	fill_rts_header


^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: [PATCH v2 1/2] change the function name s_vFillRTSHead
  2022-11-01 13:32   ` Joe Perches
@ 2022-11-01 14:55     ` Tanju Brunostar
  0 siblings, 0 replies; 7+ messages in thread
From: Tanju Brunostar @ 2022-11-01 14:55 UTC (permalink / raw)
  To: Joe Perches; +Cc: gregkh, linux-staging, linux-kernel, outreachy

On Tue, Nov 1, 2022 at 2:32 PM Joe Perches <joe@perches.com> wrote:
>
> On Tue, 2022-11-01 at 12:37 +0000, Tanjuate Brunostar wrote:
> > Remove the use of Hungarian notation, which is not used in the Linux
> > kernel. Reported by checkpatch
> []
> > diff --git a/drivers/staging/vt6655/rxtx.c b/drivers/staging/vt6655/rxtx.c
> []
> > @@ -23,7 +23,7 @@
> >   *      s_uGetTxRsvTime- get frame reserved time
> >   *      s_vFillCTSHead- fulfill CTS ctl header
> >   *      s_vFillFragParameter- Set fragment ctl parameter.
> > - *      s_vFillRTSHead- fulfill RTS ctl header
> > + *      fill_rts_head- fulfill RTS ctl header
>
> Perhaps use header as head is conventionally used in lists.
>
>         fill_rts_header
>
OK, thanks

^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: [PATCH v2 0/2] some checkpatch fixes in the file rxtx.c
  2022-11-01 12:37 [PATCH v2 0/2] some checkpatch fixes in the file rxtx.c Tanjuate Brunostar
  2022-11-01 12:37 ` [PATCH v2 1/2] change the function name s_vFillRTSHead Tanjuate Brunostar
  2022-11-01 12:38 ` [PATCH v2 2/2] Join some lines of code to avoid code lines ending in ( Tanjuate Brunostar
@ 2022-11-01 18:21 ` Greg KH
  2022-11-01 18:34   ` Tanju Brunostar
  2 siblings, 1 reply; 7+ messages in thread
From: Greg KH @ 2022-11-01 18:21 UTC (permalink / raw)
  To: Tanjuate Brunostar; +Cc: linux-staging, linux-kernel, outreachy

On Tue, Nov 01, 2022 at 12:37:58PM +0000, Tanjuate Brunostar wrote:
> These fixes are focused on the function s_vFillRTSHead
> 
> v2: changed confusing changelog messages
> 
> Tanjuate Brunostar (2):
>   change the function name s_vFillRTSHead
>   Join some lines of code to avoid code lines ending in (
> 
>  drivers/staging/vt6655/rxtx.c | 48 ++++++++++++++++-------------------
>  1 file changed, 22 insertions(+), 26 deletions(-)

Please look at your subject lines you are using here, and look at the
mailing list for previous patch submissions, and at the git log for this
file, and fix them up to have the proper prefixes on them.

As is, I can't take these.

thanks,

greg k-h

^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: [PATCH v2 0/2] some checkpatch fixes in the file rxtx.c
  2022-11-01 18:21 ` [PATCH v2 0/2] some checkpatch fixes in the file rxtx.c Greg KH
@ 2022-11-01 18:34   ` Tanju Brunostar
  0 siblings, 0 replies; 7+ messages in thread
From: Tanju Brunostar @ 2022-11-01 18:34 UTC (permalink / raw)
  To: Greg KH; +Cc: linux-staging, linux-kernel, outreachy

On Tue, Nov 1, 2022 at 7:20 PM Greg KH <gregkh@linuxfoundation.org> wrote:
>
> On Tue, Nov 01, 2022 at 12:37:58PM +0000, Tanjuate Brunostar wrote:
> > These fixes are focused on the function s_vFillRTSHead
> >
> > v2: changed confusing changelog messages
> >
> > Tanjuate Brunostar (2):
> >   change the function name s_vFillRTSHead
> >   Join some lines of code to avoid code lines ending in (
> >
> >  drivers/staging/vt6655/rxtx.c | 48 ++++++++++++++++-------------------
> >  1 file changed, 22 insertions(+), 26 deletions(-)
>
> Please look at your subject lines you are using here, and look at the
> mailing list for previous patch submissions, and at the git log for this
> file, and fix them up to have the proper prefixes on them.
>
> As is, I can't take these.
>
> thanks,
>
> greg k-h

There is a version 3 of this. Please review it instead

thanks

Tanju

^ permalink raw reply	[flat|nested] 7+ messages in thread

end of thread, other threads:[~2022-11-01 18:35 UTC | newest]

Thread overview: 7+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2022-11-01 12:37 [PATCH v2 0/2] some checkpatch fixes in the file rxtx.c Tanjuate Brunostar
2022-11-01 12:37 ` [PATCH v2 1/2] change the function name s_vFillRTSHead Tanjuate Brunostar
2022-11-01 13:32   ` Joe Perches
2022-11-01 14:55     ` Tanju Brunostar
2022-11-01 12:38 ` [PATCH v2 2/2] Join some lines of code to avoid code lines ending in ( Tanjuate Brunostar
2022-11-01 18:21 ` [PATCH v2 0/2] some checkpatch fixes in the file rxtx.c Greg KH
2022-11-01 18:34   ` Tanju Brunostar

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).